@@ -1,6 +1,8 @@
 from satsearch import Search
 import sys
 from rich import print as rprint
+import requests
+import json
 
 from felicette.utils.geo_utils import get_tiny_bbox
 from felicette.utils.sys_utils import exit_cli
@@ -9,6 +11,7 @@ from felicette.utils.file_manager import (
     save_to_file,
     data_file_exists,
     file_paths_wrt_id,
+    get_product_type_from_id,
 )
 
 
@@ -16,7 +19,7 @@ def handle_prompt_response(response):
     if response in ["n", "N"]:
         exit_cli(
             rprint,
-            "Why not try a different location next time? I'd suggest [link=https://en.wikipedia.org/wiki/Svalbard]Svalbard[/link] :)"
+            "Why not try a different location next time? I'd suggest [link=https://en.wikipedia.org/wiki/Svalbard]Svalbard[/link] :)",
         )
     elif response in ["y", "Y", ""]:
         return None
@@ -24,12 +27,22 @@ def handle_prompt_response(response):
         exit_cli(rprint, "[red]Sorry, invalid response. Exiting :([/red]")
 
 
-def search_landsat_data(coordinates, cloud_cover_lt):
+def search_satellite_data(coordinates, cloud_cover_lt, product="landsat"):
+    """
+    coordinates: bounding box's coordinates
+    cloud_cover_lt: maximum cloud cover
+    product: landsat, sentinel
+    """
+    if product == "landsat":
+        product = "landsat-8-l1"
+    elif product == "sentinel":
+        product = "sentinel-2-l1c"
+
     search = Search(
         bbox=get_tiny_bbox(coordinates),
         query={
             "eo:cloud_cover": {"lt": cloud_cover_lt},
-            "collection": {"eq": "landsat-8-l1"},
+            "collection": {"eq": product},
         },
         sort=[{"field": "eo:cloud_cover", "direction": "asc"}],
     )
@@ -39,18 +52,20 @@ def search_landsat_data(coordinates, cloud_cover_lt):
     search_items = search.items()
     if not len(search_items):
         exit_cli(print, "No data matched your search, please try different parameters.")
-    landsat_item = search_items[0]
-    return landsat_item
+
+    # return the first result
+    item = search_items[0]
+    return item
 
 
-def preview_landsat_image(landsat_item):
-    paths = file_paths_wrt_id(landsat_item._data["id"])
+def preview_satellite_image(item):
+    paths = file_paths_wrt_id(item._data["id"])
     # download image and save it in directory
     if not data_file_exists(paths["preview"]):
         save_to_file(
-            landsat_item.assets["thumbnail"]["href"],
+            item.assets["thumbnail"]["href"],
             paths["preview"],
-            landsat_item._data["id"],
+            item._data["id"],
             "✗ preview data doesn't exist, downloading image",
         )
     else:
@@ -65,6 +80,44 @@ def preview_landsat_image(landsat_item):
     return handle_prompt_response(response)
 
 
+def download_data(item, bands):
+    product_type = get_product_type_from_id(item._data["id"])
+    if product_type == "sentinel":
+        return download_sentinel_data(item, bands)
+    else:
+        return download_landsat_data(item, bands)
+
+
+def download_sentinel_data(item, bands):
+    # get paths w.r.t. id
+    paths = file_paths_wrt_id(item._data["id"])
+    # get meta info on path, to be used by boto3
+    info_response = requests.get(item.assets["info"]["href"])
+    info_response_json = json.loads(info_response.text)
+    # save bands generically
+    for band in bands:
+        # pass band id in metadata
+        info_response_json["band_id"] = band
+        band_filename = paths["b%s" % band]
+        if not data_file_exists(band_filename):
+            save_to_file(
+                item.assets["B0{}".format(band)]["href"],
+                band_filename,
+                item._data["id"],
+                "✗ required data doesn't exist, downloading %s %s"
+                % (band_tag_map["b" + str(band)], "band"),
+                meta=info_response_json,
+            )
+        else:
+            rprint(
+                "[green] ✓ ",
+                "required data exists for {} band".format(
+                    band_tag_map["b" + str(band)]
+                ),
+            )
+    return item._data["id"]
+
+
 def download_landsat_data(landsat_item, bands):
 
     # get paths w.r.t. id
