@@ -18,6 +18,7 @@ def display_file(file_name):
     elif sys.platform.startswith("darwin"):
         os.system("open %s" % file_name)
 
+
 def remove_dir(directory):
     for filename in os.listdir(directory):
         file_path = os.path.join(directory, filename)
@@ -27,5 +28,5 @@ def remove_dir(directory):
             elif os.path.isdir(file_path):
                 shutil.rmtree(file_path)
         except Exception as e:
-            print('Failed to delete %s. Reason: %s' % (file_path, e))
+            print("Failed to delete %s. Reason: %s" % (file_path, e))
             exit_cli(print, "")
